# Copyright 2023- Le Filament (https://le-filament.com)
# License AGPL-3.0 or later (http://www.gnu.org/licenses/agpl.html)

from odoo import api, fields, models


class ResCompany(models.Model):
    _inherit = "res.company"

    contract_guarantee_sequence_id = fields.Many2one(
        comodel_name="ir.sequence",
        string="Séquence des contrats de garantie",
        check_company=True,
        domain="[('company_id', '=', company_id), ('code', '=', 'financial.contract.guarantee')]",
    )
    amount_guarantee_limit = fields.Monetary("Plafond de garantie")
    fmg_rate = fields.Float("Taux FMG")
    social_share_rate = fields.Float("Taux Parts Sociales")
    social_share_amount_max = fields.Float("Plafond parts sociales (€)")

    # ------------------------------------------------------
    # Fields declaration
    # ------------------------------------------------------

    # ------------------------------------------------------
    # SQL Constraints
    # ------------------------------------------------------

    # ------------------------------------------------------
    # Default methods
    # ------------------------------------------------------

    # ------------------------------------------------------
    # Computed fields / Search Fields
    # ------------------------------------------------------

    # ------------------------------------------------------
    # Onchange / Constraints
    # ------------------------------------------------------

    # ------------------------------------------------------
    # CRUD methods (ORM overrides)
    # ------------------------------------------------------
    @api.model_create_multi
    def create(self, values):
        """
        Crée une séquence dédiée à la société
        """
        res = super().create(values)
        for company in res:
            company.contract_guarantee_sequence_id = self.env["ir.sequence"].create(
                {
                    "name": f"Contrats Financiers : Garantie - {res.name}",
                    "company_id": res.id,
                    "number_next": 1,
                    "number_increment": 1,
                    "use_date_range": True,
                    "prefix": "G%(year)s%(month)s",
                    "padding": 4,
                    "implementation": "no_gap",
                    "code": "financial.contract.guarantee",
                }
            )
        return res

    # ------------------------------------------------------
    # Actions
    # ------------------------------------------------------

    # ------------------------------------------------------
    # Business methods
    # ------------------------------------------------------
